A port of the pololu header from arduino to mbed

Dependencies:   PololuQTRSensors

source for original arduino library: https://github.com/pololu/zumo-shield/tree/master/ZumoReflectanceSensorArray

Revision:
2:4aa1484fa679
Parent:
0:4c5986aedbfc
Child:
3:e3afbfd0a71c
--- a/ZumoReflectanceSensorArray.h	Mon Oct 16 16:13:01 2017 +0000
+++ b/ZumoReflectanceSensorArray.h	Wed Oct 18 11:06:18 2017 +0000
@@ -110,10 +110,10 @@
    *
    * \param emitterPin Pin that turns IR emitters on or off.
    *
    * This constructor calls `init(unsigned char emitterPin)` with the specified
    * emitter pin and default values for other settings.
    */
-  ZumoReflectanceSensorArray(unsigned char emitterPin){
+  ZumoReflectanceSensorArray(PinName emitterPin){
     init(emitterPin);
   }
@@ -110,10 +110,10 @@
    * \param emitterPin Pin that turns IR emitters on or off.
    *
-   * This constructor calls `init(unsigned char emitterPin)` with the specified
+   * This constructor calls `init(PinName emitterPin)` with the specified
    * emitter pin and default values for other settings.
    */